Changelog
=========


(unreleased)
------------
- Release: version 0.0.1 🚀 [Dor Lugasi-Gal]
- Cat release message. [Dor Lugasi-Gal]
- Release: version 0.0.1 🚀 [Dor Lugasi-Gal]
- Merge branch 'main' of
  https://github.com/dorlugasigal/aad_fastapi_test. [Dor Lugasi-Gal]
- Delete shg.sh. [Dor Lugasi-Gal]
- Release: version 0.0.1 🚀 [Dor Lugasi-Gal]
- Release. [Dor Lugasi-Gal]
- Release: version 0.0.1 🚀 [Dor Lugasi-Gal]
- Remove matrix for now. [Dor Lugasi-Gal]
- Release: version 0.0.1 🚀 [Dor Lugasi-Gal]
- Release: version ${TAG} ≡ƒÜÇ. [Dor Lugasi-Gal]
- Release: version ${TAG} ≡ƒÜÇ. [Dor Lugasi-Gal]
- Release: version ${TAG} ≡ƒÜÇ. [Dor Lugasi-Gal]
- Merge branch 'main' of
  https://github.com/dorlugasigal/aad_fastapi_test. [Dor Lugasi-Gal]
- Merge pull request #1 from dorlugasigal/fix/readme. [Dor Lugasi-Gal]

  Update README.md
- Update README.md. [Dor Lugasi-Gal]
- Release: version 0.0.2 🚀 [Dor Lugasi-Gal]
- Release: version  🚀 [Dor Lugasi-Gal]
- Release: version 0.0.2 🚀 [Dor Lugasi-Gal]
- Release: version 0.0.2 🚀 [Dor Lugasi-Gal]
- Release: version 0.0.1 🚀 [Dor Lugasi-Gal]
- Release: version 0.0.1 🚀 [Dor Lugasi-Gal]
- Release: version 0.0.1 🚀 [Dor Lugasi-Gal]
- Release: version 0×.0.1 🚀 [Dor Lugasi-Gal]
- Release: version ${TAG} ≡ƒÜÇ. [Dor Lugasi-Gal]
- Merge branch 'main' of
  https://github.com/dorlugasigal/aad_fastapi_test. [Dor Lugasi-Gal]
- Update FUNDING.yml. [Dor Lugasi-Gal]
- Update FUNDING.yml. [Dor Lugasi-Gal]
- Update FUNDING.yml. [Dor Lugasi-Gal]
- Codecov. [Dor Lugasi-Gal]
- Remove 3.10. [Dor Lugasi-Gal]
- More matrix. [Dor Lugasi-Gal]
- Some clean up. [Dor Lugasi-Gal]
- ✅ Ready to clone and code. [dorlugasigal]
- Initial commit. [Dor Lugasi-Gal]


